@@ -3,6 +3,23 @@ from tqdm import trange
 import torch
 import numpy as np
 
+
+theo_clonal_list = {
+    "1:0" : 1,
+    "1:1" : 1,
+    "2:0" : 2,
+    "2:1" : 2,
+    "2:2" : 2
+}
+
+theo_clonal_means_list = {
+    "1:0" : 0.99999,
+    "1:1" : 0.5,
+    "2:0" : torch.tensor([0.5,0.99999]),
+    "2:1" : torch.tensor([0.333,0.666]),
+    "2:2" : torch.tensor([0.25,0.5])
+}
+
 def flatten_list(l):
     return list(flatten(l))
 
